==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_results/mp7927_001/ContractTemplateResultData.java <==

package net.datastream.schemas.mp_results.mp7927_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.CONTRACTTEMPLATEID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "contracttemplateid",
    "classid",
    "standardUserDefinedFields",
    "userdefinedarea"
})
@XmlRootElement(name = "ContractTemplateResultData")
public class ContractTemplateResultData {

    @XmlElement(name = "CONTRACTTEMPLATEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CONTRACTTEMPLATEID_Type contracttemplateid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;

    /**
     * Gets the value of the contracttemplateid property.
     * 
     * @return
     *     possible object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public CONTRACTTEMPLATEID_Type getCONTRACTTEMPLATEID() {
        return contracttemplateid;
    }

    /**
     * Sets the value of the contracttemplateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public void setCONTRACTTEMPLATEID(CONTRACTTEMPLATEID_Type value) {
        this.contracttemplateid = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the userdefinedarea property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Sets the value of the userdefinedarea property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_results/mp7927_001/ContractTemplateResultData.java <==

package net.datastream.schemas.mp_results.mp7927_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.CONTRACTTEMPLATEID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "contracttemplateid",
    "classid",
    "standardUserDefinedFields",
    "userdefinedarea"
})
@XmlRootElement(name = "ContractTemplateResultData")
public class ContractTemplateResultData {

    @XmlElement(name = "CONTRACTTEMPLATEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CONTRACTTEMPLATEID_Type contracttemplateid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;

    /**
     * Gets the value of the contracttemplateid property.
     * 
     * @return
     *     possible object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public CONTRACTTEMPLATEID_Type getCONTRACTTEMPLATEID() {
        return contracttemplateid;
    }

    /**
     * Sets the value of the contracttemplateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public void setCONTRACTTEMPLATEID(CONTRACTTEMPLATEID_Type value) {
        this.contracttemplateid = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the userdefinedarea property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Sets the value of the userdefinedarea property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

}
